@@ -97,7 +97,7 @@
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
-#define HAVE_TERMIO_H 1
+/* #undef HAVE_TERMIO_H */
 #define HAVE_TERMCAP_H 1
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
@@ -518,17 +518,17 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 12
-#define MYSQL_VERSION_MINOR 0
+#define MYSQL_VERSION_MINOR 1
 #define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 12.0.2"
+#define PACKAGE_STRING "MySQL Server 12.1.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "12.0.2"
-#define VERSION "12.0.2"
+#define PACKAGE_VERSION "12.1.2"
+#define VERSION "12.1.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
